@@ -16,6 +16,6 @@ def get_articles(start_page=1, end_page=1):
 		
 		css_path = ".ourSingle h2 a"
 		posts += parser.get_articles(g,
-			css_path, css_path, "topdesignmagazine")
+			css_path, css_path, "topdesignmagazine", "topdesignmag.com")
 	
 	return posts
